@@ -2,6 +2,7 @@
 import struct
 import ctypes
 import sys
+import time
 from ctypes import *
 
 
@@ -30,4 +31,7 @@ def cal_563_mos(degFile):
     return p563.fPredictedMos,p563.fSpeechLevel,p563.fSnr,p563.fNoiseLevel
 
 if __name__ == '__main__':
-    print(cal_563_mos(r'C:\Users\vcloud_avl\Downloads\P.563\Software\bin\123.pcm'))
\ No newline at end of file
+    for a in range(100):
+        time.sleep(20)
+        src = r'E:\audioalgorithm\audiotestalgorithm\demos\02_p563_demo\cleDstFile.wav'
+        print(cal_563_mos(src))
\ No newline at end of file
